@@ -115,7 +115,7 @@ __all__ = [
     "sleep",
     "random",
     "resume_session",
-    "StandaloneServer"
+    "StandaloneServer",
 ]
 
 sessions_model = sqlyte.model(
