@@ -170,15 +170,15 @@ class MachineBase:
     def get(self, from_path, to_path=None):
         """"""
 
-        def cp():
-            self.cp(f"{self.user}@{self.address}:{from_path}", to_path)
+        def cp(path):
+            self.cp(f"{self.user}@{self.address}:{from_path}", path)
 
         if to_path:
-            cp()
+            cp(to_path)
         else:
             with tempfile.TemporaryDirectory() as tmpdirname:
                 to_path = pathlib.Path(tmpdirname) / "alpha"
-                cp()
+                cp(to_path)
                 with to_path.open() as fp:
                     return fp.read()
 
@@ -198,7 +198,7 @@ class MachineBase:
                 "-o",
                 "StrictHostKeyChecking=no",
                 from_path,
-                f"{self.user}@{self.address}:{to_path}",
+                to_path,
             ],
             stderr=subprocess.STDOUT,
             stdout=subprocess.PIPE,
@@ -343,6 +343,51 @@ class Machine(MachineBase):
         self.runinenv = self.system_dir / "runinenv"
         self.projects_dir = self.system_dir / "projects"
 
+    def setup_tor(self):
+        """Install Tor for anonymous routing."""
+        self._apt("install -yq tor")
+        self.torrc = "/etc/tor/torrc"
+        self.tor_data = "/var/lib/tor"
+        self.run(
+            f"cat > {self.torrc}",
+            stdin=textwrap.dedent(
+                f"""\
+                HiddenServiceDir {self.tor_data}/main
+                HiddenServicePort 80 127.0.0.1:80
+
+                # leave this here for cat'ing over SSH..."""
+            ),
+        )
+        self.run("service tor restart")
+        self.onion = self.get(f"{self.tor_data}/main/hostname")
+
+    def setup_nginx(self):
+        """
+        Install Nginx (w/ TLS, HTTPv2, RTMP) for web serving.
+
+        """
+        self._apt("install -yq nginx libnginx-mod-rtmp")
+        self.nginx_conf = "/etc/nginx/nginx.conf"
+        self.web_data = "/var/www"
+        self.open_ports(80, 443)
+        protected_path = newmath.nbrandom(5)
+        self.run(f"mkdir {self.web_data}")
+        self.run(
+            f"cat > {self.web_data}/{protected_path}.html",
+            stdin=str(templates.nginx_index(self.address)),
+        )
+        self.run(
+            f"cat > {self.nginx_conf}",
+            stdin=str(templates.nginx_conf(self.address, self.onion)),
+        )
+        self.run("service nginx restart")
+        self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
+        return protected_path
+
+    def generate_dhparam(self, bits=4096):
+        """Generate a unique Diffie-Hellman prime for Nginx."""
+        self.run(f"openssl dhparam -out {self.system_dir}/dhparam.pem {bits}")
+
     def setup_python(self):
         """
         Install Python (w/ SQLite extensions) for application runtime.
@@ -372,58 +417,28 @@ class Machine(MachineBase):
         )
         self.run(f"chmod +x {self.runinenv}")
 
-    def setup_admin(self):
+    def setup_app(self, protected_path, package):
         """Install administrative interface."""
-        self.run("/root/python/bin/python3 -m venv admin")
-        self.run("runinenv admin pip install webint")
+        self.run("/root/python/bin/python3 -m venv app")
+        self.run(f"/root/runinenv app pip install {package}")
+        # TODO put web.host.admin:app behind supervisor
+        # TODO move nginx conf to conf.d's
+        #   TODO replace initial IP-site conf.d with admin server
+        # XXX self.run(
+        # XXX     f"cat > {self.torrc}",
+        # XXX     stdin=textwrap.dedent(
+        # XXX         f"""\
+        # XXX         HiddenServiceDir {self.tor_data}/main
+        # XXX         HiddenServicePort 80 127.0.0.1:80
 
-    def setup_tor(self):
-        """Install Tor for anonymous routing."""
-        self._apt("install -yq tor")
-        self.torrc = "/etc/tor/torrc"
-        self.tor_data = "/var/lib/tor"
-        self.run(
-            f"cat > {self.torrc}",
-            stdin=textwrap.dedent(
-                f"""\
-                HiddenServiceDir {self.tor_data}/main
-                HiddenServicePort 80 127.0.0.1:80"""
-            ),
-        )
-        self.run("service tor restart")
-        self.onion = self.get(f"{self.tor_data}/main/hostname")
-
-    def setup_nginx(self):
-        """
-        Install Nginx (w/ TLS, HTTPv2, RTMP) for web serving.
-
-        """
-        self._apt("install -yq nginx libnginx-mod-rtmp")
-        self.nginx_conf = "/etc/nginx/nginx.conf"
-        self.web_data = "/var/www"
-        self.open_ports(80, 443)
-        protected_path = newmath.nbrandom(5)
-        self.run(f"mkdir {self.web_data}")
-        self.run(
-            f"cat > {self.web_data}/{protected_path}.html",
-            stdin=str(templates.nginx_index(self.address)),
-        )
-        self.run(
-            f"cat > {self.nginx_conf}",
-            stdin=str(templates.nginx_conf(self.address, self.onion)),
-        )
-        self.run("service nginx restart")
-        self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
-        return protected_path
+        # XXX         # leave this here for cat'ing over SSH..."""
+        # XXX     ),
+        # XXX )
 
     # def setup_node(self):
     #     """Install Node from NodeSource."""
     #     ...
 
-    def generate_dhparam(self, bits=4096):
-        """Generate a unique Diffie-Hellman prime for Nginx."""
-        self.run(f"openssl dhparam -out {self.system_dir}/dhparam.pem {bits}")
-
     def install_project(self, registrar, project_root=Path(".")):
         """Install sites from project in `project_root`."""
         # TODO install from Git URL
